r'''
# `cloudflare_dns_settings`

Refer to the Terraform Registry for docs: [`cloudflare_dns_settings`](https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings).
'''
from pkgutil import extend_path
__path__ = extend_path(__path__, __name__)

import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import typeguard
from importlib.metadata import version as _metadata_package_version
TYPEGUARD_MAJOR_VERSION = int(_metadata_package_version('typeguard').split('.')[0])

def check_type(argname: str, value: object, expected_type: typing.Any) -> typing.Any:
    if TYPEGUARD_MAJOR_VERSION <= 2:
        return typeguard.check_type(argname=argname, value=value, expected_type=expected_type) # type:ignore
    else:
        if isinstance(value, jsii._reference_map.InterfaceDynamicProxy): # pyright: ignore [reportAttributeAccessIssue]
           pass
        else:
            if TYPEGUARD_MAJOR_VERSION == 3:
                typeguard.config.collection_check_strategy = typeguard.CollectionCheckStrategy.ALL_ITEMS # type:ignore
                typeguard.check_type(value=value, expected_type=expected_type) # type:ignore
            else:
                typeguard.check_type(value=value, expected_type=expected_type, collection_check_strategy=typeguard.CollectionCheckStrategy.ALL_ITEMS) # type:ignore

from .._jsii import *

import cdktf as _cdktf_9a9027ec
import constructs as _constructs_77d1e7e8


class DnsSettings(
    _cdktf_9a9027ec.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-cloudflare.dnsSettings.DnsSettings",
):
    '''Represents a {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings cloudflare_dns_settings}.'''

    def __init__(
        self,
        scope: _constructs_77d1e7e8.Construct,
        id: builtins.str,
        *,
        account_id: typing.Optional[builtins.str] = None,
        zone_defaults: typing.Optional[typing.Union["DnsSettingsZoneDefaults", typing.Dict[builtins.str, typing.Any]]] = None,
        zone_id: typing.Optional[builtins.str] = None,
        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
        count: typing.Optional[typing.Union[jsii.Number, _cdktf_9a9027ec.TerraformCount]] = None,
        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
    ) -> None:
        '''Create a new {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings cloudflare_dns_settings} Resource.

        :param scope: The scope in which to define this construct.
        :param id: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param account_id: The Account ID to use for this endpoint. Mutually exclusive with the Zone ID. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#account_id DnsSettings#account_id}
        :param zone_defaults: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#zone_defaults DnsSettings#zone_defaults}.
        :param zone_id: The Zone ID to use for this endpoint. Mutually exclusive with the Account ID. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#zone_id DnsSettings#zone_id}
        :param connection: 
        :param count: 
        :param depends_on: 
        :param for_each: 
        :param lifecycle: 
        :param provider: 
        :param provisioners: 
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c44e9dc90819556f6a7c20c7be28543ac91f16d89e43495ce264bf072a2cd4a9)
            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
        config = DnsSettingsConfig(
            account_id=account_id,
            zone_defaults=zone_defaults,
            zone_id=zone_id,
            connection=connection,
            count=count,
            depends_on=depends_on,
            for_each=for_each,
            lifecycle=lifecycle,
            provider=provider,
            provisioners=provisioners,
        )

        jsii.create(self.__class__, self, [scope, id, config])

    @jsii.member(jsii_name="generateConfigForImport")
    @builtins.classmethod
    def generate_config_for_import(
        cls,
        scope: _constructs_77d1e7e8.Construct,
        import_to_id: builtins.str,
        import_from_id: builtins.str,
        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
    ) -> _cdktf_9a9027ec.ImportableResource:
        '''Generates CDKTF code for importing a DnsSettings resource upon running "cdktf plan ".

        :param scope: The scope in which to define this construct.
        :param import_to_id: The construct id used in the generated config for the DnsSettings to import.
        :param import_from_id: The id of the existing DnsSettings that should be imported. Refer to the {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#import import section} in the documentation of this resource for the id to use
        :param provider: ? Optional instance of the provider where the DnsSettings to import is found.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a3f67fda8e0f9e8b8785c887989d0d3c97efe3f6428a75a627c94ce0d01c37ba)
            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
            check_type(argname="argument import_to_id", value=import_to_id, expected_type=type_hints["import_to_id"])
            check_type(argname="argument import_from_id", value=import_from_id, expected_type=type_hints["import_from_id"])
            check_type(argname="argument provider", value=provider, expected_type=type_hints["provider"])
        return typing.cast(_cdktf_9a9027ec.ImportableResource, jsii.sinvoke(cls, "generateConfigForImport", [scope, import_to_id, import_from_id, provider]))

    @jsii.member(jsii_name="putZoneDefaults")
    def put_zone_defaults(
        self,
        *,
        flatten_all_cnames: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        foundation_dns: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        internal_dns: typing.Optional[typing.Union["DnsSettingsZoneDefaultsInternalDns", typing.Dict[builtins.str, typing.Any]]] = None,
        multi_provider: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        nameservers: typing.Optional[typing.Union["DnsSettingsZoneDefaultsNameservers", typing.Dict[builtins.str, typing.Any]]] = None,
        ns_ttl: typing.Optional[jsii.Number] = None,
        secondary_overrides: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        soa: typing.Optional[typing.Union["DnsSettingsZoneDefaultsSoa", typing.Dict[builtins.str, typing.Any]]] = None,
        zone_mode: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param flatten_all_cnames: Whether to flatten all CNAME records in the zone. Note that, due to DNS limitations, a CNAME record at the zone apex will always be flattened. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#flatten_all_cnames DnsSettings#flatten_all_cnames}
        :param foundation_dns: Whether to enable Foundation DNS Advanced Nameservers on the zone. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#foundation_dns DnsSettings#foundation_dns}
        :param internal_dns: Settings for this internal zone. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#internal_dns DnsSettings#internal_dns}
        :param multi_provider: Whether to enable multi-provider DNS, which causes Cloudflare to activate the zone even when non-Cloudflare NS records exist, and to respect NS records at the zone apex during outbound zone transfers. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#multi_provider DnsSettings#multi_provider}
        :param nameservers: Settings determining the nameservers through which the zone should be available. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#nameservers DnsSettings#nameservers}
        :param ns_ttl: The time to live (TTL) of the zone's nameserver (NS) records. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#ns_ttl DnsSettings#ns_ttl}
        :param secondary_overrides: Allows a Secondary DNS zone to use (proxied) override records and CNAME flattening at the zone apex. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#secondary_overrides DnsSettings#secondary_overrides}
        :param soa: Components of the zone's SOA record. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#soa DnsSettings#soa}
        :param zone_mode: Whether the zone mode is a regular or CDN/DNS only zone. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#zone_mode DnsSettings#zone_mode}
        '''
        value = DnsSettingsZoneDefaults(
            flatten_all_cnames=flatten_all_cnames,
            foundation_dns=foundation_dns,
            internal_dns=internal_dns,
            multi_provider=multi_provider,
            nameservers=nameservers,
            ns_ttl=ns_ttl,
            secondary_overrides=secondary_overrides,
            soa=soa,
            zone_mode=zone_mode,
        )

        return typing.cast(None, jsii.invoke(self, "putZoneDefaults", [value]))

    @jsii.member(jsii_name="resetAccountId")
    def reset_account_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAccountId", []))

    @jsii.member(jsii_name="resetZoneDefaults")
    def reset_zone_defaults(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetZoneDefaults", []))

    @jsii.member(jsii_name="resetZoneId")
    def reset_zone_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetZoneId", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.member(jsii_name="synthesizeHclAttributes")
    def _synthesize_hcl_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeHclAttributes", []))

    @jsii.python.classproperty
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property
    @jsii.member(jsii_name="zoneDefaults")
    def zone_defaults(self) -> "DnsSettingsZoneDefaultsOutputReference":
        return typing.cast("DnsSettingsZoneDefaultsOutputReference", jsii.get(self, "zoneDefaults"))

    @builtins.property
    @jsii.member(jsii_name="accountIdInput")
    def account_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "accountIdInput"))

    @builtins.property
    @jsii.member(jsii_name="zoneDefaultsInput")
    def zone_defaults_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, "DnsSettingsZoneDefaults"]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, "DnsSettingsZoneDefaults"]], jsii.get(self, "zoneDefaultsInput"))

    @builtins.property
    @jsii.member(jsii_name="zoneIdInput")
    def zone_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "zoneIdInput"))

    @builtins.property
    @jsii.member(jsii_name="accountId")
    def account_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "accountId"))

    @account_id.setter
    def account_id(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__251be0cd3b0603a82a67a8dc3f8554951d3087ee5d934ec7893285faf168c24c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accountId", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="zoneId")
    def zone_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "zoneId"))

    @zone_id.setter
    def zone_id(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__edc4e42079e81e63164e42225869067b7712d1f857775a2e114fc191d0c81b53)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "zoneId", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-cloudflare.dnsSettings.DnsSettingsConfig",
    jsii_struct_bases=[_cdktf_9a9027ec.TerraformMetaArguments],
    name_mapping={
        "connection": "connection",
        "count": "count",
        "depends_on": "dependsOn",
        "for_each": "forEach",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "provisioners": "provisioners",
        "account_id": "accountId",
        "zone_defaults": "zoneDefaults",
        "zone_id": "zoneId",
    },
)
class DnsSettingsConfig(_cdktf_9a9027ec.TerraformMetaArguments):
    def __init__(
        self,
        *,
        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
        count: typing.Optional[typing.Union[jsii.Number, _cdktf_9a9027ec.TerraformCount]] = None,
        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
        account_id: typing.Optional[builtins.str] = None,
        zone_defaults: typing.Optional[typing.Union["DnsSettingsZoneDefaults", typing.Dict[builtins.str, typing.Any]]] = None,
        zone_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param connection: 
        :param count: 
        :param depends_on: 
        :param for_each: 
        :param lifecycle: 
        :param provider: 
        :param provisioners: 
        :param account_id: The Account ID to use for this endpoint. Mutually exclusive with the Zone ID. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#account_id DnsSettings#account_id}
        :param zone_defaults: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#zone_defaults DnsSettings#zone_defaults}.
        :param zone_id: The Zone ID to use for this endpoint. Mutually exclusive with the Account ID. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#zone_id DnsSettings#zone_id}
        '''
        if isinstance(lifecycle, dict):
            lifecycle = _cdktf_9a9027ec.TerraformResourceLifecycle(**lifecycle)
        if isinstance(zone_defaults, dict):
            zone_defaults = DnsSettingsZoneDefaults(**zone_defaults)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__06038c94fe9d175bce9070efdeaf0df537758a33a478d781ec14489daebe2404)
            check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
            check_type(argname="argument count", value=count, expected_type=type_hints["count"])
            check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
            check_type(argname="argument for_each", value=for_each, expected_type=type_hints["for_each"])
            check_type(argname="argument lifecycle", value=lifecycle, expected_type=type_hints["lifecycle"])
            check_type(argname="argument provider", value=provider, expected_type=type_hints["provider"])
            check_type(argname="argument provisioners", value=provisioners, expected_type=type_hints["provisioners"])
            check_type(argname="argument account_id", value=account_id, expected_type=type_hints["account_id"])
            check_type(argname="argument zone_defaults", value=zone_defaults, expected_type=type_hints["zone_defaults"])
            check_type(argname="argument zone_id", value=zone_id, expected_type=type_hints["zone_id"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if connection is not None:
            self._values["connection"] = connection
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if for_each is not None:
            self._values["for_each"] = for_each
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if provisioners is not None:
            self._values["provisioners"] = provisioners
        if account_id is not None:
            self._values["account_id"] = account_id
        if zone_defaults is not None:
            self._values["zone_defaults"] = zone_defaults
        if zone_id is not None:
            self._values["zone_id"] = zone_id

    @builtins.property
    def connection(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("connection")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]], result)

    @builtins.property
    def count(
        self,
    ) -> typing.Optional[typing.Union[jsii.Number, _cdktf_9a9027ec.TerraformCount]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[typing.Union[jsii.Number, _cdktf_9a9027ec.TerraformCount]], result)

    @builtins.property
    def depends_on(
        self,
    ) -> typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]], result)

    @builtins.property
    def for_each(self) -> typing.Optional[_cdktf_9a9027ec.ITerraformIterator]:
        '''
        :stability: experimental
        '''
        result = self._values.get("for_each")
        return typing.cast(typing.Optional[_cdktf_9a9027ec.ITerraformIterator], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[_cdktf_9a9027ec.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformProvider], result)

    @builtins.property
    def provisioners(
        self,
    ) -> typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provisioners")
        return typing.cast(typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]], result)

    @builtins.property
    def account_id(self) -> typing.Optional[builtins.str]:
        '''The Account ID to use for this endpoint. Mutually exclusive with the Zone ID.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#account_id DnsSettings#account_id}
        '''
        result = self._values.get("account_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def zone_defaults(self) -> typing.Optional["DnsSettingsZoneDefaults"]:
        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#zone_defaults DnsSettings#zone_defaults}.'''
        result = self._values.get("zone_defaults")
        return typing.cast(typing.Optional["DnsSettingsZoneDefaults"], result)

    @builtins.property
    def zone_id(self) -> typing.Optional[builtins.str]:
        '''The Zone ID to use for this endpoint. Mutually exclusive with the Account ID.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#zone_id DnsSettings#zone_id}
        '''
        result = self._values.get("zone_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DnsSettingsConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-cloudflare.dnsSettings.DnsSettingsZoneDefaults",
    jsii_struct_bases=[],
    name_mapping={
        "flatten_all_cnames": "flattenAllCnames",
        "foundation_dns": "foundationDns",
        "internal_dns": "internalDns",
        "multi_provider": "multiProvider",
        "nameservers": "nameservers",
        "ns_ttl": "nsTtl",
        "secondary_overrides": "secondaryOverrides",
        "soa": "soa",
        "zone_mode": "zoneMode",
    },
)
class DnsSettingsZoneDefaults:
    def __init__(
        self,
        *,
        flatten_all_cnames: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        foundation_dns: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        internal_dns: typing.Optional[typing.Union["DnsSettingsZoneDefaultsInternalDns", typing.Dict[builtins.str, typing.Any]]] = None,
        multi_provider: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        nameservers: typing.Optional[typing.Union["DnsSettingsZoneDefaultsNameservers", typing.Dict[builtins.str, typing.Any]]] = None,
        ns_ttl: typing.Optional[jsii.Number] = None,
        secondary_overrides: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
        soa: typing.Optional[typing.Union["DnsSettingsZoneDefaultsSoa", typing.Dict[builtins.str, typing.Any]]] = None,
        zone_mode: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param flatten_all_cnames: Whether to flatten all CNAME records in the zone. Note that, due to DNS limitations, a CNAME record at the zone apex will always be flattened. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#flatten_all_cnames DnsSettings#flatten_all_cnames}
        :param foundation_dns: Whether to enable Foundation DNS Advanced Nameservers on the zone. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#foundation_dns DnsSettings#foundation_dns}
        :param internal_dns: Settings for this internal zone. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#internal_dns DnsSettings#internal_dns}
        :param multi_provider: Whether to enable multi-provider DNS, which causes Cloudflare to activate the zone even when non-Cloudflare NS records exist, and to respect NS records at the zone apex during outbound zone transfers. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#multi_provider DnsSettings#multi_provider}
        :param nameservers: Settings determining the nameservers through which the zone should be available. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#nameservers DnsSettings#nameservers}
        :param ns_ttl: The time to live (TTL) of the zone's nameserver (NS) records. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#ns_ttl DnsSettings#ns_ttl}
        :param secondary_overrides: Allows a Secondary DNS zone to use (proxied) override records and CNAME flattening at the zone apex. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#secondary_overrides DnsSettings#secondary_overrides}
        :param soa: Components of the zone's SOA record. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#soa DnsSettings#soa}
        :param zone_mode: Whether the zone mode is a regular or CDN/DNS only zone. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#zone_mode DnsSettings#zone_mode}
        '''
        if isinstance(internal_dns, dict):
            internal_dns = DnsSettingsZoneDefaultsInternalDns(**internal_dns)
        if isinstance(nameservers, dict):
            nameservers = DnsSettingsZoneDefaultsNameservers(**nameservers)
        if isinstance(soa, dict):
            soa = DnsSettingsZoneDefaultsSoa(**soa)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7678916009523f3493dc51ad5aa75b5f63d8ad118bd26588218138cd3f897e8c)
            check_type(argname="argument flatten_all_cnames", value=flatten_all_cnames, expected_type=type_hints["flatten_all_cnames"])
            check_type(argname="argument foundation_dns", value=foundation_dns, expected_type=type_hints["foundation_dns"])
            check_type(argname="argument internal_dns", value=internal_dns, expected_type=type_hints["internal_dns"])
            check_type(argname="argument multi_provider", value=multi_provider, expected_type=type_hints["multi_provider"])
            check_type(argname="argument nameservers", value=nameservers, expected_type=type_hints["nameservers"])
            check_type(argname="argument ns_ttl", value=ns_ttl, expected_type=type_hints["ns_ttl"])
            check_type(argname="argument secondary_overrides", value=secondary_overrides, expected_type=type_hints["secondary_overrides"])
            check_type(argname="argument soa", value=soa, expected_type=type_hints["soa"])
            check_type(argname="argument zone_mode", value=zone_mode, expected_type=type_hints["zone_mode"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if flatten_all_cnames is not None:
            self._values["flatten_all_cnames"] = flatten_all_cnames
        if foundation_dns is not None:
            self._values["foundation_dns"] = foundation_dns
        if internal_dns is not None:
            self._values["internal_dns"] = internal_dns
        if multi_provider is not None:
            self._values["multi_provider"] = multi_provider
        if nameservers is not None:
            self._values["nameservers"] = nameservers
        if ns_ttl is not None:
            self._values["ns_ttl"] = ns_ttl
        if secondary_overrides is not None:
            self._values["secondary_overrides"] = secondary_overrides
        if soa is not None:
            self._values["soa"] = soa
        if zone_mode is not None:
            self._values["zone_mode"] = zone_mode

    @builtins.property
    def flatten_all_cnames(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Whether to flatten all CNAME records in the zone.

        Note that, due to DNS limitations, a CNAME record at the zone apex will always be flattened.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#flatten_all_cnames DnsSettings#flatten_all_cnames}
        '''
        result = self._values.get("flatten_all_cnames")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def foundation_dns(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Whether to enable Foundation DNS Advanced Nameservers on the zone.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#foundation_dns DnsSettings#foundation_dns}
        '''
        result = self._values.get("foundation_dns")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def internal_dns(self) -> typing.Optional["DnsSettingsZoneDefaultsInternalDns"]:
        '''Settings for this internal zone.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#internal_dns DnsSettings#internal_dns}
        '''
        result = self._values.get("internal_dns")
        return typing.cast(typing.Optional["DnsSettingsZoneDefaultsInternalDns"], result)

    @builtins.property
    def multi_provider(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Whether to enable multi-provider DNS, which causes Cloudflare to activate the zone even when non-Cloudflare NS records exist, and to respect NS records at the zone apex during outbound zone transfers.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#multi_provider DnsSettings#multi_provider}
        '''
        result = self._values.get("multi_provider")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def nameservers(self) -> typing.Optional["DnsSettingsZoneDefaultsNameservers"]:
        '''Settings determining the nameservers through which the zone should be available.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#nameservers DnsSettings#nameservers}
        '''
        result = self._values.get("nameservers")
        return typing.cast(typing.Optional["DnsSettingsZoneDefaultsNameservers"], result)

    @builtins.property
    def ns_ttl(self) -> typing.Optional[jsii.Number]:
        '''The time to live (TTL) of the zone's nameserver (NS) records.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#ns_ttl DnsSettings#ns_ttl}
        '''
        result = self._values.get("ns_ttl")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def secondary_overrides(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        '''Allows a Secondary DNS zone to use (proxied) override records and CNAME flattening at the zone apex.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#secondary_overrides DnsSettings#secondary_overrides}
        '''
        result = self._values.get("secondary_overrides")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)

    @builtins.property
    def soa(self) -> typing.Optional["DnsSettingsZoneDefaultsSoa"]:
        '''Components of the zone's SOA record.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#soa DnsSettings#soa}
        '''
        result = self._values.get("soa")
        return typing.cast(typing.Optional["DnsSettingsZoneDefaultsSoa"], result)

    @builtins.property
    def zone_mode(self) -> typing.Optional[builtins.str]:
        '''Whether the zone mode is a regular or CDN/DNS only zone.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#zone_mode DnsSettings#zone_mode}
        '''
        result = self._values.get("zone_mode")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DnsSettingsZoneDefaults(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-cloudflare.dnsSettings.DnsSettingsZoneDefaultsInternalDns",
    jsii_struct_bases=[],
    name_mapping={"reference_zone_id": "referenceZoneId"},
)
class DnsSettingsZoneDefaultsInternalDns:
    def __init__(
        self,
        *,
        reference_zone_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param reference_zone_id: The ID of the zone to fallback to. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#reference_zone_id DnsSettings#reference_zone_id}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__75c7fb81276384b270193fe8bf6aae2b585215fe0f4426e1fdcad369d9b2013a)
            check_type(argname="argument reference_zone_id", value=reference_zone_id, expected_type=type_hints["reference_zone_id"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if reference_zone_id is not None:
            self._values["reference_zone_id"] = reference_zone_id

    @builtins.property
    def reference_zone_id(self) -> typing.Optional[builtins.str]:
        '''The ID of the zone to fallback to.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#reference_zone_id DnsSettings#reference_zone_id}
        '''
        result = self._values.get("reference_zone_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DnsSettingsZoneDefaultsInternalDns(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DnsSettingsZoneDefaultsInternalDnsOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-cloudflare.dnsSettings.DnsSettingsZoneDefaultsInternalDnsOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2d808ca56efa20fa10c13628dde9bdc6ad5f3fb5a342ffbd23178a3249572cba)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetReferenceZoneId")
    def reset_reference_zone_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetReferenceZoneId", []))

    @builtins.property
    @jsii.member(jsii_name="referenceZoneIdInput")
    def reference_zone_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "referenceZoneIdInput"))

    @builtins.property
    @jsii.member(jsii_name="referenceZoneId")
    def reference_zone_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "referenceZoneId"))

    @reference_zone_id.setter
    def reference_zone_id(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b243a286c22e8dc7d10c904682afbda58368469f1a91bd91c025874f89b17c76)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "referenceZoneId", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, DnsSettingsZoneDefaultsInternalDns]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, DnsSettingsZoneDefaultsInternalDns]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, DnsSettingsZoneDefaultsInternalDns]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e47613c4bea71418bdbb53e918b4b6ed681b60976c20d67174a470495d44d7df)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-cloudflare.dnsSettings.DnsSettingsZoneDefaultsNameservers",
    jsii_struct_bases=[],
    name_mapping={"type": "type"},
)
class DnsSettingsZoneDefaultsNameservers:
    def __init__(self, *, type: builtins.str) -> None:
        '''
        :param type: Nameserver type. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#type DnsSettings#type}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d816cf30660a2943d89ca1d8482f571223d8495af2d7619c671aaf37ab182c85)
            check_type(argname="argument type", value=type, expected_type=type_hints["type"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "type": type,
        }

    @builtins.property
    def type(self) -> builtins.str:
        '''Nameserver type.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#type DnsSettings#type}
        '''
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DnsSettingsZoneDefaultsNameservers(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DnsSettingsZoneDefaultsNameserversOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-cloudflare.dnsSettings.DnsSettingsZoneDefaultsNameserversOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5d31aded6aabbdcf836ed05403456151d579eb857852e9df702230d1ce1931cf)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property
    @jsii.member(jsii_name="typeInput")
    def type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "typeInput"))

    @builtins.property
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "type"))

    @type.setter
    def type(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__aaac1decc8839830f61e7f458253a32846eaef9ca6ccc1591eb6105689ed1c9c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "type", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, DnsSettingsZoneDefaultsNameservers]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, DnsSettingsZoneDefaultsNameservers]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, DnsSettingsZoneDefaultsNameservers]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__55c68ec3e56f1c685622757671b0affd7512f86d36d8f49ad99cf421f4d507b8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


class DnsSettingsZoneDefaultsOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-cloudflare.dnsSettings.DnsSettingsZoneDefaultsOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__07d7da113f59f8bccb2b5a02e875e34ab3864cf2877da4a69f752cdeb1575ada)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putInternalDns")
    def put_internal_dns(
        self,
        *,
        reference_zone_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param reference_zone_id: The ID of the zone to fallback to. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#reference_zone_id DnsSettings#reference_zone_id}
        '''
        value = DnsSettingsZoneDefaultsInternalDns(reference_zone_id=reference_zone_id)

        return typing.cast(None, jsii.invoke(self, "putInternalDns", [value]))

    @jsii.member(jsii_name="putNameservers")
    def put_nameservers(self, *, type: builtins.str) -> None:
        '''
        :param type: Nameserver type. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#type DnsSettings#type}
        '''
        value = DnsSettingsZoneDefaultsNameservers(type=type)

        return typing.cast(None, jsii.invoke(self, "putNameservers", [value]))

    @jsii.member(jsii_name="putSoa")
    def put_soa(
        self,
        *,
        expire: jsii.Number,
        min_ttl: jsii.Number,
        mname: builtins.str,
        refresh: jsii.Number,
        retry: jsii.Number,
        rname: builtins.str,
        ttl: jsii.Number,
    ) -> None:
        '''
        :param expire: Time in seconds of being unable to query the primary server after which secondary servers should stop serving the zone. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#expire DnsSettings#expire}
        :param min_ttl: The time to live (TTL) for negative caching of records within the zone. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#min_ttl DnsSettings#min_ttl}
        :param mname: The primary nameserver, which may be used for outbound zone transfers. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#mname DnsSettings#mname}
        :param refresh: Time in seconds after which secondary servers should re-check the SOA record to see if the zone has been updated. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#refresh DnsSettings#refresh}
        :param retry: Time in seconds after which secondary servers should retry queries after the primary server was unresponsive. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#retry DnsSettings#retry}
        :param rname: The email address of the zone administrator, with the first label representing the local part of the email address. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#rname DnsSettings#rname}
        :param ttl: The time to live (TTL) of the SOA record itself. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#ttl DnsSettings#ttl}
        '''
        value = DnsSettingsZoneDefaultsSoa(
            expire=expire,
            min_ttl=min_ttl,
            mname=mname,
            refresh=refresh,
            retry=retry,
            rname=rname,
            ttl=ttl,
        )

        return typing.cast(None, jsii.invoke(self, "putSoa", [value]))

    @jsii.member(jsii_name="resetFlattenAllCnames")
    def reset_flatten_all_cnames(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFlattenAllCnames", []))

    @jsii.member(jsii_name="resetFoundationDns")
    def reset_foundation_dns(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFoundationDns", []))

    @jsii.member(jsii_name="resetInternalDns")
    def reset_internal_dns(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInternalDns", []))

    @jsii.member(jsii_name="resetMultiProvider")
    def reset_multi_provider(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMultiProvider", []))

    @jsii.member(jsii_name="resetNameservers")
    def reset_nameservers(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetNameservers", []))

    @jsii.member(jsii_name="resetNsTtl")
    def reset_ns_ttl(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetNsTtl", []))

    @jsii.member(jsii_name="resetSecondaryOverrides")
    def reset_secondary_overrides(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSecondaryOverrides", []))

    @jsii.member(jsii_name="resetSoa")
    def reset_soa(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSoa", []))

    @jsii.member(jsii_name="resetZoneMode")
    def reset_zone_mode(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetZoneMode", []))

    @builtins.property
    @jsii.member(jsii_name="internalDns")
    def internal_dns(self) -> DnsSettingsZoneDefaultsInternalDnsOutputReference:
        return typing.cast(DnsSettingsZoneDefaultsInternalDnsOutputReference, jsii.get(self, "internalDns"))

    @builtins.property
    @jsii.member(jsii_name="nameservers")
    def nameservers(self) -> DnsSettingsZoneDefaultsNameserversOutputReference:
        return typing.cast(DnsSettingsZoneDefaultsNameserversOutputReference, jsii.get(self, "nameservers"))

    @builtins.property
    @jsii.member(jsii_name="soa")
    def soa(self) -> "DnsSettingsZoneDefaultsSoaOutputReference":
        return typing.cast("DnsSettingsZoneDefaultsSoaOutputReference", jsii.get(self, "soa"))

    @builtins.property
    @jsii.member(jsii_name="flattenAllCnamesInput")
    def flatten_all_cnames_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "flattenAllCnamesInput"))

    @builtins.property
    @jsii.member(jsii_name="foundationDnsInput")
    def foundation_dns_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "foundationDnsInput"))

    @builtins.property
    @jsii.member(jsii_name="internalDnsInput")
    def internal_dns_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, DnsSettingsZoneDefaultsInternalDns]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, DnsSettingsZoneDefaultsInternalDns]], jsii.get(self, "internalDnsInput"))

    @builtins.property
    @jsii.member(jsii_name="multiProviderInput")
    def multi_provider_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "multiProviderInput"))

    @builtins.property
    @jsii.member(jsii_name="nameserversInput")
    def nameservers_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, DnsSettingsZoneDefaultsNameservers]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, DnsSettingsZoneDefaultsNameservers]], jsii.get(self, "nameserversInput"))

    @builtins.property
    @jsii.member(jsii_name="nsTtlInput")
    def ns_ttl_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "nsTtlInput"))

    @builtins.property
    @jsii.member(jsii_name="secondaryOverridesInput")
    def secondary_overrides_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "secondaryOverridesInput"))

    @builtins.property
    @jsii.member(jsii_name="soaInput")
    def soa_input(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, "DnsSettingsZoneDefaultsSoa"]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, "DnsSettingsZoneDefaultsSoa"]], jsii.get(self, "soaInput"))

    @builtins.property
    @jsii.member(jsii_name="zoneModeInput")
    def zone_mode_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "zoneModeInput"))

    @builtins.property
    @jsii.member(jsii_name="flattenAllCnames")
    def flatten_all_cnames(
        self,
    ) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "flattenAllCnames"))

    @flatten_all_cnames.setter
    def flatten_all_cnames(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__696354d70d324dfcc8e419062c9e72c2a130880658addaf40febf083723e3f3d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "flattenAllCnames", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="foundationDns")
    def foundation_dns(
        self,
    ) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "foundationDns"))

    @foundation_dns.setter
    def foundation_dns(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bba24e6c724d1a9b4774a4aa37a2057fc0e4f7dc337504ce5e32dfe6914ec2aa)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "foundationDns", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="multiProvider")
    def multi_provider(
        self,
    ) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "multiProvider"))

    @multi_provider.setter
    def multi_provider(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a8e8469001d8bf83a8cff1a1b1a048d3ee83a1c85550e9ccd3f19f1691a4925d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "multiProvider", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="nsTtl")
    def ns_ttl(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "nsTtl"))

    @ns_ttl.setter
    def ns_ttl(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__59a32b76b83341e6e76af36d8cc23eaa90a2a0463b26138dea4c143de7e9c81f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "nsTtl", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="secondaryOverrides")
    def secondary_overrides(
        self,
    ) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "secondaryOverrides"))

    @secondary_overrides.setter
    def secondary_overrides(
        self,
        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4bceb224d575799f6b990c70b62063b9530690f0381e3472337a952a90176af0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "secondaryOverrides", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="zoneMode")
    def zone_mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "zoneMode"))

    @zone_mode.setter
    def zone_mode(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__27f2f1eed4a5801d81adbd12c19724836aea40c98b496a4dedbd09d32f7cc6a0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "zoneMode", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, DnsSettingsZoneDefaults]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, DnsSettingsZoneDefaults]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, DnsSettingsZoneDefaults]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__24bfc841cb4409899e09ab15febd218735a32b03770fe1a22dbfb9316babed43)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@cdktf/provider-cloudflare.dnsSettings.DnsSettingsZoneDefaultsSoa",
    jsii_struct_bases=[],
    name_mapping={
        "expire": "expire",
        "min_ttl": "minTtl",
        "mname": "mname",
        "refresh": "refresh",
        "retry": "retry",
        "rname": "rname",
        "ttl": "ttl",
    },
)
class DnsSettingsZoneDefaultsSoa:
    def __init__(
        self,
        *,
        expire: jsii.Number,
        min_ttl: jsii.Number,
        mname: builtins.str,
        refresh: jsii.Number,
        retry: jsii.Number,
        rname: builtins.str,
        ttl: jsii.Number,
    ) -> None:
        '''
        :param expire: Time in seconds of being unable to query the primary server after which secondary servers should stop serving the zone. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#expire DnsSettings#expire}
        :param min_ttl: The time to live (TTL) for negative caching of records within the zone. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#min_ttl DnsSettings#min_ttl}
        :param mname: The primary nameserver, which may be used for outbound zone transfers. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#mname DnsSettings#mname}
        :param refresh: Time in seconds after which secondary servers should re-check the SOA record to see if the zone has been updated. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#refresh DnsSettings#refresh}
        :param retry: Time in seconds after which secondary servers should retry queries after the primary server was unresponsive. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#retry DnsSettings#retry}
        :param rname: The email address of the zone administrator, with the first label representing the local part of the email address. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#rname DnsSettings#rname}
        :param ttl: The time to live (TTL) of the SOA record itself. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#ttl DnsSettings#ttl}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__379338de58e7ce0fb9984f45cd61e3cbdfa7309eeffc909d5dcd7b1f3dd19c5b)
            check_type(argname="argument expire", value=expire, expected_type=type_hints["expire"])
            check_type(argname="argument min_ttl", value=min_ttl, expected_type=type_hints["min_ttl"])
            check_type(argname="argument mname", value=mname, expected_type=type_hints["mname"])
            check_type(argname="argument refresh", value=refresh, expected_type=type_hints["refresh"])
            check_type(argname="argument retry", value=retry, expected_type=type_hints["retry"])
            check_type(argname="argument rname", value=rname, expected_type=type_hints["rname"])
            check_type(argname="argument ttl", value=ttl, expected_type=type_hints["ttl"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "expire": expire,
            "min_ttl": min_ttl,
            "mname": mname,
            "refresh": refresh,
            "retry": retry,
            "rname": rname,
            "ttl": ttl,
        }

    @builtins.property
    def expire(self) -> jsii.Number:
        '''Time in seconds of being unable to query the primary server after which secondary servers should stop serving the zone.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#expire DnsSettings#expire}
        '''
        result = self._values.get("expire")
        assert result is not None, "Required property 'expire' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def min_ttl(self) -> jsii.Number:
        '''The time to live (TTL) for negative caching of records within the zone.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#min_ttl DnsSettings#min_ttl}
        '''
        result = self._values.get("min_ttl")
        assert result is not None, "Required property 'min_ttl' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def mname(self) -> builtins.str:
        '''The primary nameserver, which may be used for outbound zone transfers.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#mname DnsSettings#mname}
        '''
        result = self._values.get("mname")
        assert result is not None, "Required property 'mname' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def refresh(self) -> jsii.Number:
        '''Time in seconds after which secondary servers should re-check the SOA record to see if the zone has been updated.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#refresh DnsSettings#refresh}
        '''
        result = self._values.get("refresh")
        assert result is not None, "Required property 'refresh' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def retry(self) -> jsii.Number:
        '''Time in seconds after which secondary servers should retry queries after the primary server was unresponsive.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#retry DnsSettings#retry}
        '''
        result = self._values.get("retry")
        assert result is not None, "Required property 'retry' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def rname(self) -> builtins.str:
        '''The email address of the zone administrator, with the first label representing the local part of the email address.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#rname DnsSettings#rname}
        '''
        result = self._values.get("rname")
        assert result is not None, "Required property 'rname' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def ttl(self) -> jsii.Number:
        '''The time to live (TTL) of the SOA record itself.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#ttl DnsSettings#ttl}
        '''
        result = self._values.get("ttl")
        assert result is not None, "Required property 'ttl' is missing"
        return typing.cast(jsii.Number, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DnsSettingsZoneDefaultsSoa(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DnsSettingsZoneDefaultsSoaOutputReference(
    _cdktf_9a9027ec.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-cloudflare.dnsSettings.DnsSettingsZoneDefaultsSoaOutputReference",
):
    def __init__(
        self,
        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4b31f162797e54afaaa1267ef394563ee78cca759ea32023753c04766d782766)
            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property
    @jsii.member(jsii_name="expireInput")
    def expire_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "expireInput"))

    @builtins.property
    @jsii.member(jsii_name="minTtlInput")
    def min_ttl_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "minTtlInput"))

    @builtins.property
    @jsii.member(jsii_name="mnameInput")
    def mname_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "mnameInput"))

    @builtins.property
    @jsii.member(jsii_name="refreshInput")
    def refresh_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "refreshInput"))

    @builtins.property
    @jsii.member(jsii_name="retryInput")
    def retry_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "retryInput"))

    @builtins.property
    @jsii.member(jsii_name="rnameInput")
    def rname_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "rnameInput"))

    @builtins.property
    @jsii.member(jsii_name="ttlInput")
    def ttl_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "ttlInput"))

    @builtins.property
    @jsii.member(jsii_name="expire")
    def expire(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "expire"))

    @expire.setter
    def expire(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__26f500661b58cb120827e913a98f69c5de9b36ba727598aecce536dac3648471)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "expire", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="minTtl")
    def min_ttl(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "minTtl"))

    @min_ttl.setter
    def min_ttl(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f5cd8de557258c452ccbd4d1a0e7c4d155012321b86c608708be26260c227c87)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "minTtl", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="mname")
    def mname(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "mname"))

    @mname.setter
    def mname(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__26ef556f537ce7b2d38f107ab3fea2517ddad8e277e75eacebc089dc05a19a9c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "mname", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="refresh")
    def refresh(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "refresh"))

    @refresh.setter
    def refresh(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__36a88535c154900df794fad653653fe22fb8a81fcecc7d3ee3a3cb45c9bfb4a1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "refresh", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="retry")
    def retry(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "retry"))

    @retry.setter
    def retry(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e93c9611dd2f888c376b765f75c9e8e4532b6b866d63f9d3df3d453a1ad6da04)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "retry", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="rname")
    def rname(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "rname"))

    @rname.setter
    def rname(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d4a0ad7924c0c2179c4155adf9c9e6d8a8e87d4771bea3a81b5db251303caacb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "rname", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="ttl")
    def ttl(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "ttl"))

    @ttl.setter
    def ttl(self, value: jsii.Number) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a0e79c977356006b8d59ac056c6ee982eb3f3e4a7165be28e254eede89dff181)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "ttl", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, DnsSettingsZoneDefaultsSoa]]:
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, DnsSettingsZoneDefaultsSoa]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, DnsSettingsZoneDefaultsSoa]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__51f0b1157821a714585182959242f6460596f8504b9752eb781c8e637f5cfba7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "internalValue", value) # pyright: ignore[reportArgumentType]


__all__ = [
    "DnsSettings",
    "DnsSettingsConfig",
    "DnsSettingsZoneDefaults",
    "DnsSettingsZoneDefaultsInternalDns",
    "DnsSettingsZoneDefaultsInternalDnsOutputReference",
    "DnsSettingsZoneDefaultsNameservers",
    "DnsSettingsZoneDefaultsNameserversOutputReference",
    "DnsSettingsZoneDefaultsOutputReference",
    "DnsSettingsZoneDefaultsSoa",
    "DnsSettingsZoneDefaultsSoaOutputReference",
]

publication.publish()

def _typecheckingstub__c44e9dc90819556f6a7c20c7be28543ac91f16d89e43495ce264bf072a2cd4a9(
    scope: _constructs_77d1e7e8.Construct,
    id: builtins.str,
    *,
    account_id: typing.Optional[builtins.str] = None,
    zone_defaults: typing.Optional[typing.Union[DnsSettingsZoneDefaults, typing.Dict[builtins.str, typing.Any]]] = None,
    zone_id: typing.Optional[builtins.str] = None,
    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
    count: typing.Optional[typing.Union[jsii.Number, _cdktf_9a9027ec.TerraformCount]] = None,
    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a3f67fda8e0f9e8b8785c887989d0d3c97efe3f6428a75a627c94ce0d01c37ba(
    scope: _constructs_77d1e7e8.Construct,
    import_to_id: builtins.str,
    import_from_id: builtins.str,
    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__251be0cd3b0603a82a67a8dc3f8554951d3087ee5d934ec7893285faf168c24c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__edc4e42079e81e63164e42225869067b7712d1f857775a2e114fc191d0c81b53(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__06038c94fe9d175bce9070efdeaf0df537758a33a478d781ec14489daebe2404(
    *,
    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
    count: typing.Optional[typing.Union[jsii.Number, _cdktf_9a9027ec.TerraformCount]] = None,
    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
    account_id: typing.Optional[builtins.str] = None,
    zone_defaults: typing.Optional[typing.Union[DnsSettingsZoneDefaults, typing.Dict[builtins.str, typing.Any]]] = None,
    zone_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7678916009523f3493dc51ad5aa75b5f63d8ad118bd26588218138cd3f897e8c(
    *,
    flatten_all_cnames: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    foundation_dns: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    internal_dns: typing.Optional[typing.Union[DnsSettingsZoneDefaultsInternalDns, typing.Dict[builtins.str, typing.Any]]] = None,
    multi_provider: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    nameservers: typing.Optional[typing.Union[DnsSettingsZoneDefaultsNameservers, typing.Dict[builtins.str, typing.Any]]] = None,
    ns_ttl: typing.Optional[jsii.Number] = None,
    secondary_overrides: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
    soa: typing.Optional[typing.Union[DnsSettingsZoneDefaultsSoa, typing.Dict[builtins.str, typing.Any]]] = None,
    zone_mode: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__75c7fb81276384b270193fe8bf6aae2b585215fe0f4426e1fdcad369d9b2013a(
    *,
    reference_zone_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2d808ca56efa20fa10c13628dde9bdc6ad5f3fb5a342ffbd23178a3249572cba(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b243a286c22e8dc7d10c904682afbda58368469f1a91bd91c025874f89b17c76(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e47613c4bea71418bdbb53e918b4b6ed681b60976c20d67174a470495d44d7df(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, DnsSettingsZoneDefaultsInternalDns]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d816cf30660a2943d89ca1d8482f571223d8495af2d7619c671aaf37ab182c85(
    *,
    type: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5d31aded6aabbdcf836ed05403456151d579eb857852e9df702230d1ce1931cf(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aaac1decc8839830f61e7f458253a32846eaef9ca6ccc1591eb6105689ed1c9c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__55c68ec3e56f1c685622757671b0affd7512f86d36d8f49ad99cf421f4d507b8(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, DnsSettingsZoneDefaultsNameservers]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__07d7da113f59f8bccb2b5a02e875e34ab3864cf2877da4a69f752cdeb1575ada(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__696354d70d324dfcc8e419062c9e72c2a130880658addaf40febf083723e3f3d(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bba24e6c724d1a9b4774a4aa37a2057fc0e4f7dc337504ce5e32dfe6914ec2aa(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a8e8469001d8bf83a8cff1a1b1a048d3ee83a1c85550e9ccd3f19f1691a4925d(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__59a32b76b83341e6e76af36d8cc23eaa90a2a0463b26138dea4c143de7e9c81f(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4bceb224d575799f6b990c70b62063b9530690f0381e3472337a952a90176af0(
    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__27f2f1eed4a5801d81adbd12c19724836aea40c98b496a4dedbd09d32f7cc6a0(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__24bfc841cb4409899e09ab15febd218735a32b03770fe1a22dbfb9316babed43(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, DnsSettingsZoneDefaults]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__379338de58e7ce0fb9984f45cd61e3cbdfa7309eeffc909d5dcd7b1f3dd19c5b(
    *,
    expire: jsii.Number,
    min_ttl: jsii.Number,
    mname: builtins.str,
    refresh: jsii.Number,
    retry: jsii.Number,
    rname: builtins.str,
    ttl: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4b31f162797e54afaaa1267ef394563ee78cca759ea32023753c04766d782766(
    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
    terraform_attribute: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__26f500661b58cb120827e913a98f69c5de9b36ba727598aecce536dac3648471(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f5cd8de557258c452ccbd4d1a0e7c4d155012321b86c608708be26260c227c87(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__26ef556f537ce7b2d38f107ab3fea2517ddad8e277e75eacebc089dc05a19a9c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__36a88535c154900df794fad653653fe22fb8a81fcecc7d3ee3a3cb45c9bfb4a1(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e93c9611dd2f888c376b765f75c9e8e4532b6b866d63f9d3df3d453a1ad6da04(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d4a0ad7924c0c2179c4155adf9c9e6d8a8e87d4771bea3a81b5db251303caacb(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a0e79c977356006b8d59ac056c6ee982eb3f3e4a7165be28e254eede89dff181(
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__51f0b1157821a714585182959242f6460596f8504b9752eb781c8e637f5cfba7(
    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, DnsSettingsZoneDefaultsSoa]],
) -> None:
    """Type checking stubs"""
    pass
