/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataCloudflareDnsSettingsConfig extends cdktf.TerraformMetaArguments {
    /**
    * The Account ID to use for this endpoint. Mutually exclusive with the Zone ID.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/data-sources/dns_settings#account_id DataCloudflareDnsSettings#account_id}
    */
    readonly accountId?: string;
    /**
    * The Zone ID to use for this endpoint. Mutually exclusive with the Account ID.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/data-sources/dns_settings#zone_id DataCloudflareDnsSettings#zone_id}
    */
    readonly zoneId?: string;
}
export interface DataCloudflareDnsSettingsZoneDefaultsInternalDns {
}
export declare function dataCloudflareDnsSettingsZoneDefaultsInternalDnsToTerraform(struct?: DataCloudflareDnsSettingsZoneDefaultsInternalDns): any;
export declare function dataCloudflareDnsSettingsZoneDefaultsInternalDnsToHclTerraform(struct?: DataCloudflareDnsSettingsZoneDefaultsInternalDns): any;
export declare class DataCloudflareDnsSettingsZoneDefaultsInternalDnsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataCloudflareDnsSettingsZoneDefaultsInternalDns | undefined;
    set internalValue(value: DataCloudflareDnsSettingsZoneDefaultsInternalDns | undefined);
    get referenceZoneId(): string;
}
export interface DataCloudflareDnsSettingsZoneDefaultsNameservers {
}
export declare function dataCloudflareDnsSettingsZoneDefaultsNameserversToTerraform(struct?: DataCloudflareDnsSettingsZoneDefaultsNameservers): any;
export declare function dataCloudflareDnsSettingsZoneDefaultsNameserversToHclTerraform(struct?: DataCloudflareDnsSettingsZoneDefaultsNameservers): any;
export declare class DataCloudflareDnsSettingsZoneDefaultsNameserversOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataCloudflareDnsSettingsZoneDefaultsNameservers | undefined;
    set internalValue(value: DataCloudflareDnsSettingsZoneDefaultsNameservers | undefined);
    get type(): string;
}
export interface DataCloudflareDnsSettingsZoneDefaultsSoa {
}
export declare function dataCloudflareDnsSettingsZoneDefaultsSoaToTerraform(struct?: DataCloudflareDnsSettingsZoneDefaultsSoa): any;
export declare function dataCloudflareDnsSettingsZoneDefaultsSoaToHclTerraform(struct?: DataCloudflareDnsSettingsZoneDefaultsSoa): any;
export declare class DataCloudflareDnsSettingsZoneDefaultsSoaOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataCloudflareDnsSettingsZoneDefaultsSoa | undefined;
    set internalValue(value: DataCloudflareDnsSettingsZoneDefaultsSoa | undefined);
    get expire(): number;
    get minTtl(): number;
    get mname(): string;
    get refresh(): number;
    get retry(): number;
    get rname(): string;
    get ttl(): number;
}
export interface DataCloudflareDnsSettingsZoneDefaults {
}
export declare function dataCloudflareDnsSettingsZoneDefaultsToTerraform(struct?: DataCloudflareDnsSettingsZoneDefaults): any;
export declare function dataCloudflareDnsSettingsZoneDefaultsToHclTerraform(struct?: DataCloudflareDnsSettingsZoneDefaults): any;
export declare class DataCloudflareDnsSettingsZoneDefaultsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataCloudflareDnsSettingsZoneDefaults | undefined;
    set internalValue(value: DataCloudflareDnsSettingsZoneDefaults | undefined);
    get flattenAllCnames(): cdktf.IResolvable;
    get foundationDns(): cdktf.IResolvable;
    private _internalDns;
    get internalDns(): DataCloudflareDnsSettingsZoneDefaultsInternalDnsOutputReference;
    get multiProvider(): cdktf.IResolvable;
    private _nameservers;
    get nameservers(): DataCloudflareDnsSettingsZoneDefaultsNameserversOutputReference;
    get nsTtl(): number;
    get secondaryOverrides(): cdktf.IResolvable;
    private _soa;
    get soa(): DataCloudflareDnsSettingsZoneDefaultsSoaOutputReference;
    get zoneMode(): string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/data-sources/dns_settings cloudflare_dns_settings}
*/
export declare class DataCloudflareDnsSettings extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "cloudflare_dns_settings";
    /**
    * Generates CDKTF code for importing a DataCloudflareDnsSettings resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataCloudflareDnsSettings to import
    * @param importFromId The id of the existing DataCloudflareDnsSettings that should be imported. Refer to the {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/data-sources/dns_settings#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataCloudflareDnsSettings to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/data-sources/dns_settings cloudflare_dns_settings} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataCloudflareDnsSettingsConfig = {}
    */
    constructor(scope: Construct, id: string, config?: DataCloudflareDnsSettingsConfig);
    private _accountId?;
    get accountId(): string;
    set accountId(value: string);
    resetAccountId(): void;
    get accountIdInput(): string | undefined;
    private _zoneDefaults;
    get zoneDefaults(): DataCloudflareDnsSettingsZoneDefaultsOutputReference;
    private _zoneId?;
    get zoneId(): string;
    set zoneId(value: string);
    resetZoneId(): void;
    get zoneIdInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
