/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DnsSettingsConfig extends cdktf.TerraformMetaArguments {
    /**
    * The Account ID to use for this endpoint. Mutually exclusive with the Zone ID.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#account_id DnsSettings#account_id}
    */
    readonly accountId?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#zone_defaults DnsSettings#zone_defaults}
    */
    readonly zoneDefaults?: DnsSettingsZoneDefaults;
    /**
    * The Zone ID to use for this endpoint. Mutually exclusive with the Account ID.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#zone_id DnsSettings#zone_id}
    */
    readonly zoneId?: string;
}
export interface DnsSettingsZoneDefaultsInternalDns {
    /**
    * The ID of the zone to fallback to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#reference_zone_id DnsSettings#reference_zone_id}
    */
    readonly referenceZoneId?: string;
}
export declare function dnsSettingsZoneDefaultsInternalDnsToTerraform(struct?: DnsSettingsZoneDefaultsInternalDns | cdktf.IResolvable): any;
export declare function dnsSettingsZoneDefaultsInternalDnsToHclTerraform(struct?: DnsSettingsZoneDefaultsInternalDns | cdktf.IResolvable): any;
export declare class DnsSettingsZoneDefaultsInternalDnsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DnsSettingsZoneDefaultsInternalDns | cdktf.IResolvable | undefined;
    set internalValue(value: DnsSettingsZoneDefaultsInternalDns | cdktf.IResolvable | undefined);
    private _referenceZoneId?;
    get referenceZoneId(): string;
    set referenceZoneId(value: string);
    resetReferenceZoneId(): void;
    get referenceZoneIdInput(): string | undefined;
}
export interface DnsSettingsZoneDefaultsNameservers {
    /**
    * Nameserver type
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#type DnsSettings#type}
    */
    readonly type: string;
}
export declare function dnsSettingsZoneDefaultsNameserversToTerraform(struct?: DnsSettingsZoneDefaultsNameservers | cdktf.IResolvable): any;
export declare function dnsSettingsZoneDefaultsNameserversToHclTerraform(struct?: DnsSettingsZoneDefaultsNameservers | cdktf.IResolvable): any;
export declare class DnsSettingsZoneDefaultsNameserversOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DnsSettingsZoneDefaultsNameservers | cdktf.IResolvable | undefined;
    set internalValue(value: DnsSettingsZoneDefaultsNameservers | cdktf.IResolvable | undefined);
    private _type?;
    get type(): string;
    set type(value: string);
    get typeInput(): string | undefined;
}
export interface DnsSettingsZoneDefaultsSoa {
    /**
    * Time in seconds of being unable to query the primary server after which secondary servers should stop serving the zone.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#expire DnsSettings#expire}
    */
    readonly expire: number;
    /**
    * The time to live (TTL) for negative caching of records within the zone.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#min_ttl DnsSettings#min_ttl}
    */
    readonly minTtl: number;
    /**
    * The primary nameserver, which may be used for outbound zone transfers.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#mname DnsSettings#mname}
    */
    readonly mname: string;
    /**
    * Time in seconds after which secondary servers should re-check the SOA record to see if the zone has been updated.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#refresh DnsSettings#refresh}
    */
    readonly refresh: number;
    /**
    * Time in seconds after which secondary servers should retry queries after the primary server was unresponsive.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#retry DnsSettings#retry}
    */
    readonly retry: number;
    /**
    * The email address of the zone administrator, with the first label representing the local part of the email address.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#rname DnsSettings#rname}
    */
    readonly rname: string;
    /**
    * The time to live (TTL) of the SOA record itself.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#ttl DnsSettings#ttl}
    */
    readonly ttl: number;
}
export declare function dnsSettingsZoneDefaultsSoaToTerraform(struct?: DnsSettingsZoneDefaultsSoa | cdktf.IResolvable): any;
export declare function dnsSettingsZoneDefaultsSoaToHclTerraform(struct?: DnsSettingsZoneDefaultsSoa | cdktf.IResolvable): any;
export declare class DnsSettingsZoneDefaultsSoaOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DnsSettingsZoneDefaultsSoa | cdktf.IResolvable | undefined;
    set internalValue(value: DnsSettingsZoneDefaultsSoa | cdktf.IResolvable | undefined);
    private _expire?;
    get expire(): number;
    set expire(value: number);
    get expireInput(): number | undefined;
    private _minTtl?;
    get minTtl(): number;
    set minTtl(value: number);
    get minTtlInput(): number | undefined;
    private _mname?;
    get mname(): string;
    set mname(value: string);
    get mnameInput(): string | undefined;
    private _refresh?;
    get refresh(): number;
    set refresh(value: number);
    get refreshInput(): number | undefined;
    private _retry?;
    get retry(): number;
    set retry(value: number);
    get retryInput(): number | undefined;
    private _rname?;
    get rname(): string;
    set rname(value: string);
    get rnameInput(): string | undefined;
    private _ttl?;
    get ttl(): number;
    set ttl(value: number);
    get ttlInput(): number | undefined;
}
export interface DnsSettingsZoneDefaults {
    /**
    * Whether to flatten all CNAME records in the zone. Note that, due to DNS limitations, a CNAME record at the zone apex will always be flattened.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#flatten_all_cnames DnsSettings#flatten_all_cnames}
    */
    readonly flattenAllCnames?: boolean | cdktf.IResolvable;
    /**
    * Whether to enable Foundation DNS Advanced Nameservers on the zone.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#foundation_dns DnsSettings#foundation_dns}
    */
    readonly foundationDns?: boolean | cdktf.IResolvable;
    /**
    * Settings for this internal zone.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#internal_dns DnsSettings#internal_dns}
    */
    readonly internalDns?: DnsSettingsZoneDefaultsInternalDns;
    /**
    * Whether to enable multi-provider DNS, which causes Cloudflare to activate the zone even when non-Cloudflare NS records exist, and to respect NS records at the zone apex during outbound zone transfers.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#multi_provider DnsSettings#multi_provider}
    */
    readonly multiProvider?: boolean | cdktf.IResolvable;
    /**
    * Settings determining the nameservers through which the zone should be available.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#nameservers DnsSettings#nameservers}
    */
    readonly nameservers?: DnsSettingsZoneDefaultsNameservers;
    /**
    * The time to live (TTL) of the zone's nameserver (NS) records.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#ns_ttl DnsSettings#ns_ttl}
    */
    readonly nsTtl?: number;
    /**
    * Allows a Secondary DNS zone to use (proxied) override records and CNAME flattening at the zone apex.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#secondary_overrides DnsSettings#secondary_overrides}
    */
    readonly secondaryOverrides?: boolean | cdktf.IResolvable;
    /**
    * Components of the zone's SOA record.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#soa DnsSettings#soa}
    */
    readonly soa?: DnsSettingsZoneDefaultsSoa;
    /**
    * Whether the zone mode is a regular or CDN/DNS only zone.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#zone_mode DnsSettings#zone_mode}
    */
    readonly zoneMode?: string;
}
export declare function dnsSettingsZoneDefaultsToTerraform(struct?: DnsSettingsZoneDefaults | cdktf.IResolvable): any;
export declare function dnsSettingsZoneDefaultsToHclTerraform(struct?: DnsSettingsZoneDefaults | cdktf.IResolvable): any;
export declare class DnsSettingsZoneDefaultsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DnsSettingsZoneDefaults | cdktf.IResolvable | undefined;
    set internalValue(value: DnsSettingsZoneDefaults | cdktf.IResolvable | undefined);
    private _flattenAllCnames?;
    get flattenAllCnames(): boolean | cdktf.IResolvable;
    set flattenAllCnames(value: boolean | cdktf.IResolvable);
    resetFlattenAllCnames(): void;
    get flattenAllCnamesInput(): boolean | cdktf.IResolvable | undefined;
    private _foundationDns?;
    get foundationDns(): boolean | cdktf.IResolvable;
    set foundationDns(value: boolean | cdktf.IResolvable);
    resetFoundationDns(): void;
    get foundationDnsInput(): boolean | cdktf.IResolvable | undefined;
    private _internalDns;
    get internalDns(): DnsSettingsZoneDefaultsInternalDnsOutputReference;
    putInternalDns(value: DnsSettingsZoneDefaultsInternalDns): void;
    resetInternalDns(): void;
    get internalDnsInput(): cdktf.IResolvable | DnsSettingsZoneDefaultsInternalDns | undefined;
    private _multiProvider?;
    get multiProvider(): boolean | cdktf.IResolvable;
    set multiProvider(value: boolean | cdktf.IResolvable);
    resetMultiProvider(): void;
    get multiProviderInput(): boolean | cdktf.IResolvable | undefined;
    private _nameservers;
    get nameservers(): DnsSettingsZoneDefaultsNameserversOutputReference;
    putNameservers(value: DnsSettingsZoneDefaultsNameservers): void;
    resetNameservers(): void;
    get nameserversInput(): cdktf.IResolvable | DnsSettingsZoneDefaultsNameservers | undefined;
    private _nsTtl?;
    get nsTtl(): number;
    set nsTtl(value: number);
    resetNsTtl(): void;
    get nsTtlInput(): number | undefined;
    private _secondaryOverrides?;
    get secondaryOverrides(): boolean | cdktf.IResolvable;
    set secondaryOverrides(value: boolean | cdktf.IResolvable);
    resetSecondaryOverrides(): void;
    get secondaryOverridesInput(): boolean | cdktf.IResolvable | undefined;
    private _soa;
    get soa(): DnsSettingsZoneDefaultsSoaOutputReference;
    putSoa(value: DnsSettingsZoneDefaultsSoa): void;
    resetSoa(): void;
    get soaInput(): cdktf.IResolvable | DnsSettingsZoneDefaultsSoa | undefined;
    private _zoneMode?;
    get zoneMode(): string;
    set zoneMode(value: string);
    resetZoneMode(): void;
    get zoneModeInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings cloudflare_dns_settings}
*/
export declare class DnsSettings extends cdktf.TerraformResource {
    static readonly tfResourceType = "cloudflare_dns_settings";
    /**
    * Generates CDKTF code for importing a DnsSettings resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DnsSettings to import
    * @param importFromId The id of the existing DnsSettings that should be imported. Refer to the {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DnsSettings to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.1.0/docs/resources/dns_settings cloudflare_dns_settings} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DnsSettingsConfig = {}
    */
    constructor(scope: Construct, id: string, config?: DnsSettingsConfig);
    private _accountId?;
    get accountId(): string;
    set accountId(value: string);
    resetAccountId(): void;
    get accountIdInput(): string | undefined;
    private _zoneDefaults;
    get zoneDefaults(): DnsSettingsZoneDefaultsOutputReference;
    putZoneDefaults(value: DnsSettingsZoneDefaults): void;
    resetZoneDefaults(): void;
    get zoneDefaultsInput(): cdktf.IResolvable | DnsSettingsZoneDefaults | undefined;
    private _zoneId?;
    get zoneId(): string;
    set zoneId(value: string);
    resetZoneId(): void;
    get zoneIdInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
